import 'reflect-metadata';
import { ParamInputModel, RangeInputModel, DecoratorReturnModel, DataTypeEnum } from './reflect-input.models';
export declare function ModelState<T extends {
    new (...args: any[]): {};
}>(constructor: T): {
    new (...args: any[]): {
        /**
         * Returns model validation state
         */
        IsValid(): boolean;
        /**
         * Placeholder(string)
         * Validate: function
         */
        ModelErrors(): {
            [key: string]: {
                [key: string]: any;
            };
        };
    };
} & T;
/**
 * Validates field if it has valid value according to value parameter
 */
export declare function DataType(param: {
    value: DataTypeEnum;
    error?: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates field if it represents valid credit card number
 */
export declare function CreditCard(param: {
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Compares field to other field and checks if they are equal
 */
export declare function Compare(param: {
    field: string;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates if field value contains specific value
 */
export declare function Contains(param: {
    value: string;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates field according to custom logic
 */
export declare function Custom(param: {
    value?: any;
    error: string;
    customFunc: (...args: any[]) => any;
}): (target: any, propertyKey: string) => void;
/**
 * Sets the name metadata for the field
 */
export declare function Name(param: string): (target: any, propertyKey: string) => void;
/**
 * Validates field and checks if it has null, undefined or empty value
 */
export declare function Required(param: string): (target: any, propertyKey: string) => void;
/**
 * Validates field if other field has specific value and checks if it has null, undefined or empty value
 */
export declare function RequiredIf(param: {
    field: string;
    value: any;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Sets field's input value to readonly
 */
export declare function ReadOnly(): (target: any, propertyKey: string) => void;
/**
 * Validates if field has valid value according to specified pattern
 */
export declare function Pattern(param: {
    value: RegExp;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates if field has valid value more than specific value
 */
export declare function MinValue(input: {
    value: number | Date;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates if field has valid value less than specific value
 */
export declare function MaxValue(input: {
    value: number | Date;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates if field value does not contain specific value
 */
export declare function NotContains(param: {
    value: string;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Tells form generator component not to generate input for this field
 */
export declare function NoForm(): (target: any, propertyKey: string) => void;
/**
 * Validates if field value length fits in min and max values
 */
export declare function StringLength(input: {
    min?: number;
    max?: number;
    error: string;
}): (target: any, propertyKey: string) => void;
/**
 * Validates if field value is valid email value
 */
export declare function Email(input: string): (target: any, propertyKey: string) => void;
/**
 * Sets placeholder value for field input
 */
export declare function Placeholder(input: string): (target: any, propertyKey: string) => void;
/**
 * Validates if field value length fits in min and max values
 */
export declare function Range(input: {
    min?: number | Date;
    max?: number | Date;
    error: string;
}): (target: any, propertyKey: string) => void;
export declare function configurable(value: boolean): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 * Placeholder(string)
 * Validate: function
 */
export declare function getDecorators(target: any, propertyName: string | symbol): DecoratorReturnModel[];
export declare function ngxValidate(key: string, param: string | ParamInputModel | RangeInputModel, value: any, dataModel?: any): string;
